@@ -1,26 +1,36 @@
 # -*- coding: utf-8 -*-
 
-import os
+import sys,os
+import neuronvisio
 
-from pkg_resources import parse_version
-import pkginfo
+#def _egg_info(path_to_egg='../'):
+#    path_to_egg = os.path.join(
+#        os.path.dirname(__file__), path_to_egg)
+#    egg_info = pkginfo.Develop(path_to_egg)
+#    release = egg_info.version
+#    parsed_version = parse_version(release)
+#    version = '%s.%s' % tuple([int(x) for x in parsed_version[0:2]])
+#    return egg_info.name, egg_info.author, version, release
 
-def _egg_info(path_to_egg='../'):
-    path_to_egg = os.path.join(
-        os.path.dirname(__file__), path_to_egg)
-    egg_info = pkginfo.Develop(path_to_egg)
-    release = egg_info.version
-    parsed_version = parse_version(release)
-    version = '%s.%s' % tuple([int(x) for x in parsed_version[0:2]])
-    return egg_info.name, egg_info.author, version, release
 
-project, author, version, release = _egg_info()
-copyright = '2009, Michele Mattioni'
+project = "Neuronvisio"
+author = neuronvisio.__authors__
+version = neuronvisio.__version__ 
+release = version
+copyright = '2009 -2012, Michele Mattioni'
 
 # Extension
 extensions = ['sphinx.ext.autodoc', 'sphinx.ext.intersphinx', 'sphinx.ext.todo', 
 'sphinx.ext.coverage', 'sphinx.ext.pngmath', 'sphinx.ext.ifconfig', 
-'sphinx.ext.autosummary', 'github.tools.sphinx']
+'sphinx.ext.autosummary']
+
+# Adding githubtool only if building for github.
+# not available on readthedocs.
+try:
+    import github.tools.sphinx
+    extensions.append('github.tools.sphinx')
+except:
+    pass
 
 intersphinx_mapping = {'http://docs.python.org/': None}
 htmlhelp_basename = 'Neuronvisiodoc'
@@ -119,7 +129,7 @@ latex_paper_size = 'a4'
 # latex build settings
 latex_documents = [
     ('index', '%s.tex' % project, u'%s Documentation' % project,
-    author, 'manual'),
+    "Michele Mattioni", 'manual', True),
 ]
 
 # The name of an image file (relative to this directory) to place at the top of
@@ -128,7 +138,7 @@ latex_documents = [
 
 # For "manual" documents, if this is true, then toplevel headings are parts,
 # not chapters.
-#latex_use_parts = False
+latex_use_parts = False
 
 # Additional stuff for the LaTeX preamble.
 #latex_preamble = ''
