@@ -20,5 +20,20 @@
 #
 #"""
 
-__authors__ = 'Michele Mattioni <mattioni@ebi.ac.uk>'
-__version__ = '0.4.4'
+__authors__ = ['Michele Mattioni', 'Uri Cohen']
+__authors_emails__ = ['<mattioni@ebi.ac.uk>', '<uri.cohen@alice.nc.huji.ac.il>']
+__version__ = '0.8.0'
+
+
+import os
+# this add the commit of to the software version when run from a git repo
+try:
+    import git
+    if git.__version__ == '0.3.1':
+        if git.repo.fun.is_git_dir(os.path.join(root, ".git")):
+            r = git.Repo(root)
+            git_commit = r.head.commit.hexsha
+            __version__ = __version__ + ' : ' + git_commit
+        raise ImportError
+except ImportError:
+    pass
