@@ -4,7 +4,6 @@ from paver.setuputils import setup
 #from setuptools import setup
 from setuptools import find_packages
 import sys, os
-sys.path.append('./src')
 import neuronvisio
 
 try:
@@ -23,6 +22,8 @@ except ImportError, e:
 
 
 version = neuronvisio.__version__
+authors = neuronvisio.__authors__
+authors_email = neuronvisio.__authors_emails__
 
 classifiers = [
     # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
@@ -35,6 +36,9 @@ classifiers = [
 install_requires = [
     # -*- Install requires: -*-
     'setuptools',
+    'ipython>=0.12',
+    'traitsui>=4.1.1.dev',
+    'mayavi>=4.1.1.dev',
     ]
 
 entry_points="""
@@ -48,13 +52,14 @@ setup(
     description='NeuronVisio is a Graphical User Interface for NEURON simulator enviroment',
     long_description=open('README.rst', 'r').read(),
     packages = ['neuronvisio', 'neuronvisio.modeldb'],
-    package_dir={'neuronvisio': 'src/neuronvisio'},
+    package_dir={'neuronvisio': 'neuronvisio'},
     package_data=paver.setuputils.find_package_data(package="neuronvisio", ),
-    scripts= ['src/nrnvisio.py'],
+    scripts= ['bin/neuronvisio', 'bin/neuronvisio.bat', 
+              'bin/neuronvisio-modeldb-updater'],
     classifiers=classifiers,
     keywords='neuron, gui, pylab, 3D, visualization',
-    author='Michele Mattioni',
-    author_email='mattioni@ebi.ac.uk',
+    author=authors,
+    author_email=authors_email,
     url='http://mattions.github.com/neuronvisio/',
     license='GPLv3',
     include_package_data=True,
@@ -75,19 +80,6 @@ options(
         builddir="_build",
         sourcedir=""
         ),
-    virtualenv=Bunch(
-        packages_to_install=[
-            # -*- Virtualenv packages to install: -*-
-            'github-tools',
-            "nose",
-            "Sphinx>=0.6b1",
-            "pkginfo", 
-            "virtualenv"],
-        dest_dir='./virtual-env/',
-        install_paver=True,
-        script_name='bootstrap.py',
-        paver_command_line=None
-        ),
     )
 
 #options.setup.package_data=paver.setuputils.find_package_data(
@@ -96,7 +88,7 @@ options(
 if ALL_TASKS_LOADED:
     @task
     @needs('generate_setup', 'minilib', 'gh_pages_build_fix', 
-           'setuptools.command.sdist')
+           'distutils.command.sdist')
     def sdist():
         """Overrides sdist to make sure that our setup.py is generated."""
         print "Package baked."
